__version__ = "0.1.0"
__title__ = "pytest-snail"
__description__ = "Plugin for adding a marker to slow running tests. 🐌"
__url__ = "https://github.com/hackebrot/pytest-snail"

__author__ = "Raphael Pierzina"
__email__ = "raphael@hackebrot.de"

__license__ = "MIT License"
__copyright__ = "Copyright (c) 2019 Raphael Pierzina"
